@@ -20,7 +20,7 @@
 #include "history_p.h"
 
 #include <kcalutils/stringify.h>
-#include <KLocale>
+#include <KLocalizedString>
 
 Entry::Entry( const Akonadi::Item &item,
               const QString &description,
@@ -89,8 +89,8 @@ CreationEntry::CreationEntry( const Akonadi::Item &item, const QString &descript
   Q_ASSERT( mItems.count() == 1 );
   const Incidence::Ptr incidence = mItems.first().payload<KCalCore::Incidence::Ptr>();
   if ( mDescription.isEmpty() ) {
-    mDescription = i18n( "%1 creation",
-                         KCalUtils::Stringify::incidenceType( incidence->type() ) );
+    mDescription = i18nc( "%1 is event, todo or journal", "%1 creation",
+                          KCalUtils::Stringify::incidenceType( incidence->type() ) );
   }
   connect( mChanger, SIGNAL(createFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
             SLOT(onCreateFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)) );
@@ -141,7 +141,7 @@ void CreationEntry::onCreateFinished( int changeId, const Akonadi::Item &item,
                                       Akonadi::IncidenceChanger::ResultCode resultCode,
                                       const QString &errorString )
 {
-  if ( mChangeIds.contains( changeId ) ) { 
+  if ( mChangeIds.contains( changeId ) ) {
     if ( resultCode == IncidenceChanger::ResultCodeSuccess ) {
       mLatestRevisionByItemId.insert( item.id(), item.revision() );
       Q_ASSERT( mItems.count() == 1 );
@@ -160,10 +160,9 @@ DeletionEntry::DeletionEntry( const Akonadi::Item::List &items, const QString &d
                               History *q ) : Entry( items, description, q )
 {
   const Incidence::Ptr incidence = items.first().payload<KCalCore::Incidence::Ptr>();
-  //TODO i18n
   if ( mDescription.isEmpty() ) {
-    mDescription = i18n( "%1 deletion",
-                         KCalUtils::Stringify::incidenceType( incidence->type() ) );
+    mDescription = i18nc( "%1 is event, todo or journal", "%1 deletion",
+                          KCalUtils::Stringify::incidenceType( incidence->type() ) );
   }
   connect( mChanger, SIGNAL(createFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
             SLOT(onCreateFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)) );
@@ -247,8 +246,8 @@ ModificationEntry::ModificationEntry( const Akonadi::Item &item,
 {
   const Incidence::Ptr incidence = mItems.first().payload<KCalCore::Incidence::Ptr>();
   if ( mDescription.isEmpty() ) {
-    mDescription =  i18n( "%1 modification",
-                          KCalUtils::Stringify::incidenceType( incidence->type() ) );
+    mDescription =  i18nc( "%1 is event, todo or journal", "%1 modification",
+                           KCalUtils::Stringify::incidenceType( incidence->type() ) );
   }
 
   connect( mChanger, SIGNAL(modifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
@@ -322,8 +321,14 @@ bool MultiEntry::undo()
   mOperationInProgress = TypeUndo;
   Q_ASSERT( !mEntries.isEmpty() );
   mFinishedEntries = 0;
-  foreach( const Entry::Ptr &entry, mEntries )
-    entry->doIt( TypeUndo );
+
+  const int count = mEntries.count();
+  // To undo a batch of changes we iterate in reverse order so we don't violate
+  // causality.
+  for( int i=count-1; i>=0; --i ) {
+    mEntries[i]->doIt( TypeUndo );
+  }
+
   mChanger->endAtomicOperation();
   return true;
 }
