@@ -26,10 +26,12 @@
 #include "smsdialog.h"
 
 #include <kabc/phonenumber.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <krun.h>
 
+#include <QPointer>
+
 static QString strippedSmsNumber( const QString &number )
 {
   QString result;
@@ -48,10 +50,13 @@ void SendSmsAction::sendSms( const KABC::PhoneNumber &phoneNumber )
 {
   const QString number = phoneNumber.number().trimmed();
 
-  SmsDialog dlg( number );
-  if ( !dlg.exec() ) { // the cancel button has been clicked
+  QPointer<SmsDialog> dlg( new SmsDialog( number ) );
+  if ( dlg->exec() != QDialog::Accepted ) { // the cancel button has been clicked
+    delete dlg;
     return;
   }
+  const QString message = ( dlg != 0 ? dlg->message() : QString() );
+  delete dlg;
 
   // synchronize
   ContactActionsSettings::self()->readConfig();
@@ -59,7 +64,7 @@ void SendSmsAction::sendSms( const KABC::PhoneNumber &phoneNumber )
   //   we handle skype separated
   if ( ContactActionsSettings::self()->sendSmsAction() == ContactActionsSettings::UseSkypeSms ) {
     QSkypeDialer dialer( QLatin1String( "AkonadiContacts" ) );
-    if ( dialer.sendSms( number, dlg.message() ) ) {
+    if ( dialer.sendSms( number, message ) ) {
       // I'm not sure whether here should be a notification.
       // Skype can do a notification itself if whished.
     } else {
@@ -82,8 +87,8 @@ void SendSmsAction::sendSms( const KABC::PhoneNumber &phoneNumber )
    */
   command = command.replace( QLatin1String( "%N" ), phoneNumber.number() );
   command = command.replace( QLatin1String( "%n" ), strippedSmsNumber( number ) );
-  command = command.replace( QLatin1String( "%t" ), dlg.message() );
+  command = command.replace( QLatin1String( "%t" ), message );
   //Bug: 293232 In KDE3 We used %F to replace text
-  command = command.replace( QLatin1String( "%F" ), dlg.message() );
+  command = command.replace( QLatin1String( "%F" ), message );
   KRun::runCommand( command, 0 );
 }
