@@ -29,6 +29,8 @@
 #include <kabc/addressee.h>
 
 #include <klocale.h>
+#include <klocalizedstring.h>
+#include <kglobal.h>
 
 #include <QGridLayout>
 #include <QLabel>
@@ -74,8 +76,12 @@ class ContactEditorDialog::Private
       connect( mEditor, SIGNAL(contactStored(Akonadi::Item)),
                q, SIGNAL(contactStored(Akonadi::Item)) );
 
+      connect( mEditor, SIGNAL(error(QString)),
+               q, SIGNAL(error(QString)) );
+
       connect( q, SIGNAL(okClicked()), q, SLOT(slotOkClicked()) );
       connect( q, SIGNAL(cancelClicked()), q, SLOT(slotCancelClicked()) );
+      connect( mEditor, SIGNAL(finished()), q, SLOT(slotFinish()) );
 
       q->setInitialSize( QSize( 800, 500 ) );
     }
@@ -85,10 +91,12 @@ class ContactEditorDialog::Private
       if ( mAddressBookBox ) {
         mEditor->setDefaultAddressBook( mAddressBookBox->currentCollection() );
       }
+      mEditor->saveContactInAddressBook();
+    }
 
-      if ( mEditor->saveContact() ) {
-        q->accept();
-      }
+    void slotFinish()
+    {
+        q->KDialog::accept();
     }
 
     void slotCancelClicked()
@@ -141,4 +149,10 @@ ContactEditor* ContactEditorDialog::editor() const
   return d->mEditor;
 }
 
+
+void ContactEditorDialog::accept()
+{
+    //Nothing
+}
+
 #include "moc_contacteditordialog.cpp"
