@@ -78,6 +78,18 @@ class Akonadi::ItemFetchJobPrivate : public JobPrivate
     void startFetchJob();
     void selectDone( KJob * job );
 
+    QString jobDebuggingString() const /*Q_DECL_OVERRIDE*/ {
+      if ( mRequestedItems.isEmpty() ) {
+        return QString::fromLatin1( "All items from collection %1" ).arg( mCollection.id() );
+      } else {
+        try {
+          return QString::fromLatin1( ProtocolHelper::entitySetToByteArray( mRequestedItems, AKONADI_CMD_ITEMFETCH ) );
+        } catch ( const Exception &e ) {
+          return QString::fromUtf8( e.what() );
+        }
+      }
+    }
+
     Q_DECLARE_PUBLIC( ItemFetchJob )
 
     Collection mCollection;
