@@ -29,7 +29,7 @@
 #include <kmime/kmime_message.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kurl.h>
 
 #include <QCoreApplication>
