@@ -22,7 +22,7 @@
 #include "signature.h"
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <kconfiggroup.h>
 #include <kurl.h>
